% Script for "Programming with Matlab"
% Prepared by Giberto E. Urroz, August 2004
echo on
% Function 'AreaTrap.m' -- see page 2
help AreaTrap
pause

% Area inline function:
Area2 = inline('(b+z.*y).*y','b','y','z')
pause

% Evaluation of functions:
b = 2; z = 1.5; y = 0.75; 
A1 = AreaTrap(b,y,z)
A2 = Area2(b,y,z)
pause

% Applications with vector arguments:
b = [1, 2, 3]; z = [0.5, 1.0, 1.5]; y = [0.25, 0.50, 0.75];
A1 = AreaTrap(b,y,z)
A2 = Area2(b,y,z)
pause

% Function CC in page 3 -- coordinate conversion
help CC
pause

% Evaluation of function CC
[x,y,z] = CC(2.5,pi/6,pi/8)  % with assignment to x,y,z
pause

CC(2.5,pi/6,pi/8)            % without assignment, only value of z shows up
pause

% Using vector arguments

rho = [3.5, 2.2, 1.5]; theta = [pi/6, pi/4, pi/3]; phi = [pi/12, pi/16, pi/18];
[x,y,z] = CC(rho,theta,phi)
pause

% Function in page 4 is 'fp4.m' -- evaluation follows:
x = [1;2;3]
fp4(x)
pause

% Function in page 5 is 'JMatrix.m' -- evaluation follows:
x = [2;-1]
JMatrix(x)
pause

% Function in page 6 is 'FlowClassification1.m' -- evaluation follows:
FlowClassification1(1000,0.5)
pause
FlowClassification1(10000,1.0)
pause
FlowClassification1(4000,2.1)
pause

% Function 'FlowClassification.m' from page 7 is evaluated next:
FlowClassification
pause

% Function in page 8 is 'MySort1.m' -- evaluation follows:
u = round(10*rand(1,10))
MySort1(u)
pause

sort(u)       % pre-programmed sorting function
fliplr(ans)   % decreasing order if needed
pause

% Function 'MySort.m' in page 9 -- evaluation follows:
u = round(10*rand(1,10))
MySort(u,'i')
pause
MySort(u,'d')
pause

% Function 'swapVector.m' in page 10 -- evaluation follows:

u = [-10:1:-1]    % even number of elements
swapVector(u)
pause 

u = [1:9]         % odd number of elements
swapVector(u)
pause

fliplr(u)         % pre-programmed function
pause

% Function 'Area.m' in page 11 -- evaluation follows:
Area
pause

% Simple output examples:
% Displaying a string:
disp('Hello, world')
pause

% String with accompanying value:
A = 2.3; disp(strcat('A = ',num2str(A)))
pause

% using 'fprintf':
A = 24.5; k = 2;
fprintf('\nThe area is %10.f for iteration number %5d.\n',A,k)
pause

% Using '\n' for new line generation:
fprintf('\nThe area is %10.f \nfor iteration number %5d.\n',A,k)
pause

% Function in pages 11/12 is 'myTable1.m' -- evaluation follows:
myTable1
pause

% Function 'myTable.m' in p. 13 is used next:
myTable
pause

% Next evaluations use loops -- functions 'sum1', 'sum2', 'sum2x2', etc.
% For function 'sum1':
nn = [0:10];           % vector of values of n (nn)
m = length(nn);        % length of vector nn
SS = [];               % initialize vector SS as an empty matrix
   for j = 1:m         % This loop fills out the vector SS
SS = [SS sum1(nn(j))]; % with values calculated
end                    % from function sum1(n)
plot(nn,SS) 
pause

% For function 'sum2':
nn = [0:10]; SS = sum2(nn); plot(nn,SS)
pause

% For function 'sum2x2':
sum2x2(3,2)    % single evaluation
pause

% Filling out a matrix:
for i = 1:3
   for j = 1:4
      S(i,j) = sum2x2(i,j);
   end;
end;
S
pause

% Function 'f2eval.m' in page 17 is evaluated next:
f00 = inline('x.*sin(y)','x','y')
pause
x = [1:1:3]
y = [2:1:5]
z = f2eval(x,y,f00)
pause

% Alternate evaluation with pre-defined functions:
[X,Y] = meshgrid(x,y)
pause
f00(X,Y)
pause

% Or, use function 'feval':
feval(f00,X,Y)
pause

% Functions meshgrid and feval, or f2eval, can be used for evaluating 
% matrix of functions of two variables to produce surface plots. 
% Example using 'f2eval' (an user-defined function):
f01 = inline('x.*sin(y)+y.*sin(x)','x','y')
x = [0:0.5:10]; y = [-2.5:0.5:2.5];
z = f2eval(x,y,f01);
surf(x,y,z')
pause
mesh(x,y,z')
pause
waterfall(x,y,z')
pause

% Function 'matrixmult.m' in page 20 is evaluated next:
A = round(10*rand(3,4))
B = round(10*rand(4,6))
pause

C = matrixmult(A,B)   
pause

% Same as:
C = A*B
pause

% Do not try B*A -- it'll give an error
pause

% Function 'readTable.m' in page 21 is evaluated next:
% Enter file name: 'c:\table1.txt' when prompted.
readTable
pause

% Function 'myTableFile.m' in page 22 is evaluated next:
% Enter file name: 'c:\table2.txt' when prompted.
myTableFile
% Open file written with a text editor to see contents
% End of script